Installation
============

**liana** requires Python version >= 3.7 to run.

Development Version
-------------------

To stay up-to-date with the newest version, run:

.. code-block:: console

   pip install git+https://github.com/saezlab/liana-py


To update stable version from pip, run:

.. code-block:: console

   pip install liana
